=====
Views
=====

Kogia Pages
===========

``PageDetail``
--------------

.. autoclass:: kogia.pages.views.PageDetail
   :members:


``PageList``
------------

.. autoclass:: kogia.pages.views.PageList
   :members:
